import glob
import os
from pathlib import Path

import axipy
from PySide2.QtCore import QFile
from PySide2.QtGui import Qt
from PySide2.QtSql import QSqlDatabase, QSqlTableModel, QSqlQuery
from PySide2.QtUiTools import QUiLoader
from PySide2.QtWidgets import QWidget, QTableWidgetItem

#from LoggerMws import MwsLogger
from LoggerMws.ui.add_helper.dbSqlite import DbSqlite


class TableViewWidget(QWidget):
    def __init__(self,parent=None):
        super().__init__(parent)

        self.ui = self.load_ui("form_jornal.ui", parent)
        self.ui.cb_list_db.currentIndexChanged.connect(self.__change_db)
        self.__update_list_db=False
        self.__initDb()
        self.ui.pb_open_mws.clicked.connect(self.__load_mws)
    def __loadListDb(self):
        from LoggerMws import MwsLogger
        path_folder=MwsLogger.getFolderLoggerMws()
        folter_folder_path=str(Path(path_folder).joinpath("*.db"))

        list_db = glob.glob(folter_folder_path)
        self.__update_list_db = True
        self.ui.cb_list_db.clear()

        for name_file in list_db:
            name=str(Path(name_file).stem)
            self.ui.cb_list_db.addItem(name)
        self.__update_list_db=False
        index=len(list_db)

        if index>1:
            self.ui.cb_list_db.setCurrentIndex(index-1)
        else:
            self.__change_db(0)
    def __change_db(self,index):
        if self.__update_list_db:
            return
        select_tab=self.ui.cb_list_db.currentText()
        if self.ui.cb_list_db.count()==1:
            select_tab=self.ui.cb_list_db.itemText(0)
        if select_tab=="":
            print("no select_tab")
            return
        from LoggerMws import MwsLogger
        path_file_db=str(Path(MwsLogger.getFolderLoggerMws()).joinpath(select_tab+".db"))
        print("change db:"+path_file_db)
        self.__openDb(path_file_db)
        self.__fillTable_Z()
    def load_ui(self,name_resource,parent):
        loader = QUiLoader()
        path = os.path.join(os.path.dirname(__file__),name_resource)
        ui_file = QFile(path)
        ui_file.open(QFile.ReadOnly)
        ui  = loader.load(ui_file,parent)
        ui_file.close()
        return ui
    def initDataWidget(self):
        self.__loadListDb()
    def show(self):
        self.__loadLiastDb()
        self.ui.show()
    def __initDb(self):
        #self.__conDb = QSqlDatabase.addDatabase("QSQLITE")
        self.__db=None
    def __openDb(self,path_db):
        if self.__db is not None:
            self.__db.close()
        self.__db=DbSqlite(path_db)
        self.__db.connect()
    def closeDb(self):
        if self.__db is not None:
            self.__db.close()
            self.__db=None
    def __load_mws(self):
        id_row_select=self.ui.tableWidget.currentRow()
        data_id=self.ui.tableWidget.item(id_row_select, 0)
        id_db_rec=int(data_id.text())
        sql_select="select mws from journal where id="+str(id_db_rec)
        rows_select=self.__db.select(sql_select)
        mws_source=rows_select[0][0]
        isCloaseAll=self.ui.checkBox_closeAll.isChecked()
        if not isCloaseAll or axipy.data_manager.count==0:
            axipy.Workspace().load_string(mws_source)
        else:
            self.__observer=axipy.observer_manager.HasTables
            self.__curent_load_mws=mws_source
            self.__observer.changed.connect(self.__waitCloseAll)
            axipy.data_manager.remove_all()
    def __waitCloseAll(self):
        if not self.__observer.value:
            self.__observer.changed.disconnect(self.__waitCloseAll)
            axipy.Workspace().load_string(self.__curent_load_mws)
    def __fillTable_Z(self):
        self.ui.tableWidget.clear()
        self.ui.tableWidget.clearContents()
        self.ui.tableWidget.setRowCount(0)
        self.ui.tableWidget.setColumnCount(5)

        self.ui.tableWidget.setHorizontalHeaderLabels(["id","Дата", "Время", "Метка","Доп.инфо"])
        #query = QSqlQuery("select [id],[дата],[время] ,  [метка] , [add_info] from journal order by [время] DESC")

        rows=self.__db.select("select [id],[дата],[время] ,  [метка] , [add_info] from journal order by [время] DESC")
        countRows=len(rows)
        self.ui.tableWidget.setRowCount(countRows)
        for i,row in enumerate(rows):

            self.ui.tableWidget.setItem(i, 0, QTableWidgetItem(str(row[0])))

            self.ui.tableWidget.setItem(i, 1, QTableWidgetItem(row[1]))

            self.ui.tableWidget.setItem(i, 2, QTableWidgetItem(row[2]))

            self.ui.tableWidget.setItem(i, 3, QTableWidgetItem(row[3]))
            self.ui.tableWidget.setItem(i, 4, QTableWidgetItem(row[4]))
        self.ui.tableWidget.resizeColumnsToContents()
        self.ui.tableWidget.selectRow(0)

    def __fillTable(self):
        self.ui.tableView.setModel(None)
        self.__model = QSqlTableModel(self.ui)

        self.__model.setTable("jornel_view")
        self.__model.setEditStrategy(QSqlTableModel.OnFieldChange)
        self.__model.setHeaderData(0, Qt.Horizontal, "id")

        self.__model.setHeaderData(1, Qt.Horizontal, "Дата")

        self.__model.setHeaderData(2, Qt.Horizontal, "Время")

        self.__model.setHeaderData(3, Qt.Horizontal, "Метка")
        self.__model.setHeaderData(3, Qt.Horizontal, "Доп.инфо")

        self.__model.select()
        self.ui.tableView.setModel(self.__model)

        self.ui.tableView.resizeColumnsToContents()


